﻿using System.Drawing;
using System.Runtime.InteropServices;
using System.Windows.Forms;

namespace LegoPixelSpaceInvaders
{
    public class Player
    {
        [DllImport("user32.dll")]
        static extern short GetAsyncKeyState(System.Windows.Forms.Keys vKey); 
        
        private Point m_Position;
        private Swarm m_Swarm;
        private PacMan m_PacMan;
        private bool m_PacEnter;
        private bool m_Dead;
        private Projectile m_Projectile;

        public Player(Point position, Swarm swarm)
        {
            m_Position = position;
            m_Swarm = swarm;
            m_PacMan = new PacMan();
            m_Projectile = new Projectile();
        }

        public void Update(IAudioContext context)
        {
            if (m_Swarm.PacDeath > 1)
            {
                if(!m_PacEnter)
                    m_PacMan.Position = new Point(m_Swarm.PacPos.X + 5, m_Swarm.PacPos.Y + 4);

                m_PacEnter = true;
                m_PacMan.Update(context);
                m_PacMan.Position = new Point(m_Position.X + 6, m_PacMan.Position.Y + 1);

                m_Projectile.Update(context);

                double balance = (double)m_PacMan.Position.X / 113.0;
                balance *= 200;
                balance -= 100;

                if (m_Projectile.Position.Y < m_PacMan.Position.Y + 7 && !m_Projectile.Idle)
                {
                    context.PlaySound("fressen", (int)balance);
                    m_Projectile.Idle = true;
                }

                if (m_PacMan.Position.Y == 72)
                    context.PlaySound("rülpser_cut", (int)balance);
            }
            else
                m_Swarm.Update(context);

            if (GetAsyncKeyState(Keys.Left) < 0)
                m_Position.X -= 1;

            if (GetAsyncKeyState(Keys.Right) < 0)
                m_Position.X += 1;

            if (m_Position.X < -20)
                m_Position.X = 120;

            if (m_Position.X > 120)
                m_Position.X = -20;

            if ((m_Position.Y < m_PacMan.Position.Y - 5) && (!m_Dead))
            {
                double balance = (double)m_PacMan.Position.X / 113.0;
                balance *= 200;
                balance -= 100;

                context.PlaySound("fressen", (int)balance);
                m_Dead = true;
            }

            if (GetAsyncKeyState(Keys.Space) < 0)
            {
                if (m_PacEnter)
                    m_Projectile.Position = new Point(m_Position.X + 6, m_Position.Y);
                else
                    m_Swarm.Shoot(new Point(m_Position.X + 6, m_Position.Y));
            }

            if(GetAsyncKeyState(Keys.M) < 0)
                m_Swarm.ShootMissile(new Point(m_Position.X + 6, m_Position.Y - 7));
        }

        public void Draw(IDrawingContext context)
        {
            if (!m_PacEnter)
                m_Swarm.Draw(context);
            else
                m_Projectile.Draw(context);

            Color color = Color.Lime;

            if (!m_Dead)
            {
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 0, color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 1, color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 1, color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 1, color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 2, color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 2, color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 2, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 11, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 11, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 12, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 11, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 12, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 11, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 12, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 11, m_Position.Y + 7, color);
                context.DrawPixel(m_Position.X + 12, m_Position.Y + 7, color);
            }

            if (m_PacEnter)
                m_PacMan.Draw(context);
        }
    }
}
